@@ -34,14 +34,12 @@ def calc_beam_size(s_uu, s_vv, s_uv) -> tuple:
     """
     with np.errstate(divide='ignore'):
         uv_squared = s_uv ** 2
-        u_minus_v = s_uu - s_vv
-        u_plus_v = s_uu + s_vv
-        sqrt_param = np.sqrt(u_minus_v ** 2 + 4.0 * uv_squared)
-        plus_param = u_plus_v + sqrt_param
-        minus_param = u_plus_v - sqrt_param
-        bmaj = 2.0 * np.sqrt(np.log(2.0)) / np.pi / np.sqrt(minus_param)  # Major axis in radians
-        bmin = 2.0 * np.sqrt(np.log(2.0)) / np.pi / np.sqrt(plus_param)  # Minor axis in radians
-        bpa = -0.5 * np.arctan2(2.0 * s_uv, u_minus_v)  # Angle in radians
+        uu_minus_vv = s_uu - s_vv
+        uu_plus_vv = s_uu + s_vv
+        sqrt_in = np.sqrt(4.0 * uv_squared + (uu_minus_vv ** 2))
+        bmaj = 2.0 * np.sqrt(np.log(2.0)) / np.pi / np.sqrt(uu_plus_vv - sqrt_in)  # Major axis in radians
+        bmin = 2.0 * np.sqrt(np.log(2.0)) / np.pi / np.sqrt(uu_plus_vv + sqrt_in)  # Minor axis in radians
+        bpa = -0.5 * np.arctan2(2.0 * s_uv, uu_minus_vv)  # Angle in radians
         return bmaj * u.rad, bmin * u.rad, bpa * u.rad
 
 
@@ -201,9 +199,9 @@ class Dataset:
 
         nstokes = len(stokes)
 
-        s_uu = np.zeros(nstokes, dtype=np.float64)
-        s_vv = np.zeros(nstokes, dtype=np.float64)
-        s_uv = np.zeros(nstokes, dtype=np.float64)
+        s_uu = da.zeros(nstokes, dtype=np.float64)
+        s_vv = da.zeros(nstokes, dtype=np.float64)
+        s_uv = da.zeros(nstokes, dtype=np.float64)
         weight_sum = np.zeros(nstokes, dtype=np.float32)
 
         for ms in self.ms_list:
@@ -221,6 +219,8 @@ class Dataset:
             uvw_lambdas = array_unit_conversion(array=uvw_broadcast, unit=u.lambdas,
                                                 equivalencies=lambdas_equivalencies(restfreq=chans_broadcast))
 
+            uvw_lambdas = da.map_blocks(lambda x: x.value, uvw_lambdas, dtype=np.float64)
+
             uvw_lambdas = uvw_lambdas.reshape((len(uvw_lambdas) * nchans, 3))
             weight_broadcast = da.repeat(weight.data, nchans, axis=0)
             flag = flag.data.reshape((len(flag.data) * nchans, ncorrs))
@@ -234,9 +234,9 @@ class Dataset:
             _s_vv = da.sum(weight_broadcast * _v ** 2, axis=0)
             _s_uv = da.sum(weight_broadcast * _u * _v, axis=0)
 
-            _s_uu = _s_uu.compute().value
-            _s_vv = _s_vv.compute().value
-            _s_uv = _s_uv.compute().value
+            # _s_uu = _s_uu.compute().value
+            # _s_vv = _s_vv.compute().value
+            # _s_uv = _s_uv.compute().value
 
             for i in idx_corrs:
                 if corr_names[i] == "XX":
@@ -339,6 +339,7 @@ class Dataset:
         s_vv[weight_sum > 0.0] /= weight_sum[weight_sum > 0.0]
         s_uv[weight_sum > 0.0] /= weight_sum[weight_sum > 0.0]
 
+        s_uu, s_vv, s_uv = da.compute(s_uu, s_vv, s_uv)
         bmaj, bmin, bpa = calc_beam_size(s_uu, s_vv, s_uv)
 
         psf_objects = []
@@ -353,5 +354,3 @@ class Dataset:
             self.psf = psf_objects[0]
         else:
             self.psf = psf_objects
-
-
