@@ -21,12 +21,11 @@ class HermitianSymmetry(Transformer, metaclass=ABCMeta):
         Applies hermitian symmetry to the dataset
         """
         for ms in self.input_data.ms_list:
-            uvw_aux = xr.apply_ufunc(lambda x: x.value, ms.visibilities.uvw, dask="parallelized",
-                                     output_dtypes=[ms.visibilities.uvw.dtype])
+            bool_array = xr.apply_ufunc(lambda x: x.value < 0.0, ms.visibilities.uvw[:, 0], dask="parallelized",
+                                        output_dtypes=[bool])
             # This is faster than using the indexes as dask arrays
-            idx = da.argwhere(uvw_aux[:, 0] < 0).squeeze().compute()
+            idx = da.argwhere(bool_array).squeeze().compute()
             if len(idx) > 0:
-                uvw_aux[idx] *= -1
-                ms.visibilities.uvw = uvw_aux * un.m
+                ms.visibilities.uvw = xr.where(bool_array, ms.visibilities.uvw * -1.0, ms.visibilities.uvw)
                 ms.visibilities.data[idx] = da.conj(ms.visibilities.data[idx])
                 ms.visibilities.model[idx] = da.conj(ms.visibilities.data[idx])
